<?php
if (isset($attributes['services']) && is_array($attributes['services'])) {
    $services = $attributes['services'];
} else {
    $services = [];
}

// Ensure the lineSpace attribute is set, otherwise default to 1
$lineSpace = $attributes['lineSpace'] ?? 1;

// Get labels with default values
$totalCostLabel = $attributes['totalCostLabel'] ?? 'Costo Total';
$monthlyCostLabel = $attributes['monthlyCostLabel'] ?? 'Costo Mensual';
$separateMonthlyTotal = $attributes['separateMonthlyTotal'] ?? false;
$totalSectionTitle = $attributes['totalSectionTitle'] ?? 'Total Cost';
$monthlySectionTitle = $attributes['monthlySectionTitle'] ?? 'Monthly Cost';

// Font sizes in rem
$sectionTitleFontSize = $attributes['sectionTitleFontSize'] ?? 1.125;
$serviceNameFontSize = $attributes['serviceNameFontSize'] ?? 1;
$costLabelFontSize = $attributes['costLabelFontSize'] ?? 1;
$sectionTitleColor = $attributes['sectionTitleColor'] ?? '#000000';

// Colors for checkboxes
$checkmarkColor = $attributes['checkmarkColor'] ?? '#000000';
$mandatoryCheckboxColor = $attributes['mandatoryCheckboxColor'] ?? '#f0f0f0';
?>

<style>
/* Style for checkbox checkmark */
input[type="checkbox"]:checked {
    background-color: white;
    border-color: <?php echo esc_attr($checkmarkColor); ?>;
}

input[type="checkbox"]:checked:after {
    content: '';
    position: absolute;
    top: 40%;
    left: 50%;
    width: 6px;
    height: 10px;
    border: solid;
    border-width: 0 2px 2px 0;
    transform: translate(-50%, -50%) rotate(45deg);
    border-color: <?php echo esc_attr($checkmarkColor); ?>;
}

/* Style for mandatory service checkboxes */
input[type="checkbox"][disabled] {
    background-color: <?php echo esc_attr($mandatoryCheckboxColor); ?>;
    border-color: #ccc;
}

input[type="checkbox"][disabled]:checked:after {
    border-color: white; /* White tick */
}
</style>

<div <?php echo get_block_wrapper_attributes(); ?>>
    <div class="services-container" style="color: <?php echo esc_attr($attributes['textColor'] ?? '#000000'); ?>">
        <?php if ($separateMonthlyTotal): ?>
            <div class="total-services">
                <h3 style="text-align: center; font-size: <?php echo esc_attr($sectionTitleFontSize); ?>rem; color: <?php echo esc_attr($sectionTitleColor); ?>;"><?php echo esc_html($totalSectionTitle); ?></h3>
                <?php foreach ($services as $index => $service):
                    $isMandatory = $service['isMandatoryService'] ?? false;
                    if (!($service['isMonthly'] ?? false)): ?>
                        <div class="service-item" data-index="<?php echo $index; ?>" style="margin-bottom: <?php echo esc_attr($lineSpace); ?>rem;">
                            <div class="service-name-container">
                                <input type="checkbox" class="service-checkbox" data-cost="<?php echo esc_attr($service['cost'] ?? '0'); ?>" data-monthly="false" <?php echo $isMandatory ? 'checked disabled' : ''; ?>>
                                <span class="service-name" style="font-size: <?php echo esc_attr($serviceNameFontSize); ?>rem;"><?php echo esc_html($service['service'] ?? ''); ?></span>
                            </div>
                            <span class="service-cost" style="font-size: <?php echo esc_attr($serviceNameFontSize); ?>rem;">$<?php echo esc_html($service['cost'] ?? '0'); ?></span>
                        </div>
                    <?php endif;
                endforeach; ?>
            </div>
            <div class="monthly-services">
                <h3 style="text-align: center; font-size: <?php echo esc_attr($sectionTitleFontSize); ?>rem; color: <?php echo esc_attr($sectionTitleColor); ?>;"><?php echo esc_html($monthlySectionTitle); ?></h3>
                <?php foreach ($services as $index => $service):
                    $isMandatory = $service['isMandatoryService'] ?? false;
                    if ($service['isMonthly'] ?? false): ?>
                        <div class="service-item" data-index="<?php echo $index; ?>" style="margin-bottom: <?php echo esc_attr($lineSpace); ?>rem;">
                            <div class="service-name-container">
                                <input type="checkbox" class="service-checkbox" data-cost="<?php echo esc_attr($service['cost'] ?? '0'); ?>" data-monthly="true" <?php echo $isMandatory ? 'checked disabled' : ''; ?>>
                                <span class="service-name" style="font-size: <?php echo esc_attr($serviceNameFontSize); ?>rem;"><?php echo esc_html($service['service'] ?? ''); ?></span>
                            </div>
                            <span class="service-cost" style="font-size: <?php echo esc_attr($serviceNameFontSize); ?>rem;">$<?php echo esc_html($service['cost'] ?? '0'); ?></span>
                        </div>
                    <?php endif;
                endforeach; ?>
            </div>
        <?php else: ?>
            <?php foreach ($services as $index => $service):
                $isMandatory = $service['isMandatoryService'] ?? false; ?>
                <div class="service-item" data-index="<?php echo $index; ?>" style="margin-bottom: <?php echo esc_attr($lineSpace); ?>rem;">
                    <div class="service-name-container">
                        <input type="checkbox" class="service-checkbox" data-cost="<?php echo esc_attr($service['cost'] ?? '0'); ?>" data-monthly="<?php echo ($service['isMonthly'] ?? false) ? 'true' : 'false'; ?>" <?php echo $isMandatory ? 'checked disabled' : ''; ?>>
                        <span class="service-name" style="font-size: <?php echo esc_attr($serviceNameFontSize); ?>rem;"><?php echo esc_html($service['service'] ?? ''); ?></span>
                    </div>
                    <span class="service-cost" style="font-size: <?php echo esc_attr($serviceNameFontSize); ?>rem;">$<?php echo esc_html($service['cost'] ?? '0'); ?></span>
                </div>
            <?php endforeach; ?>
        <?php endif; ?>
        <div class="costs-container">
        <div class="total-cost" style="font-size: <?php echo esc_attr($costLabelFontSize); ?>rem; margin-top:3rem;"><?php echo esc_html($totalCostLabel); ?>: <span id="total-cost">0</span></div>
        <div class="monthly-cost" style="font-size: <?php echo esc_attr($costLabelFontSize); ?>rem;"><?php echo esc_html($monthlyCostLabel); ?>: <span id="monthly-cost">0</span></div>
        </div>
    </div>
</div>
